@@ -77,10 +77,12 @@ private:
      * 更新侧边栏控制图标按钮的状态
      */
     void updateSidebarIconStatus();
+    void updateSearchEditPlaceHolder();
 
 protected:
     void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
     bool eventFilter(QObject *o, QEvent *e) override;
+    void changeEvent(QEvent *e) override;
 signals:
     void signalSetButtonFocus();
     void signalSearchFocusSwitch();
@@ -108,7 +110,9 @@ private:
     DSearchEdit *m_searchEdit {nullptr};
     DIconButton *m_newScheduleBtn {nullptr}; //全局的新建日程按钮
     DIconButton *m_searchPush {nullptr};
+    QString     m_strPlaceHolder;
     Title_State m_showState {Title_State_Normal};
+    bool m_clickShowLeft = false;
 };
 
 #endif // CTITLEWIDGET_H
