@@ -142,7 +142,7 @@ void CDayWindow::updateShowDate(const bool isUpdateBar)
     int w = m_scheduleView->width() - 72;
     m_scheduleView->setRange(w, 1032, getSelectDate(), getSelectDate());
     //设置时间显示格式
-    m_scheduleView->setTimeFormat((m_calendarManager->getTimeShowType()?"AP ":"") + m_calendarManager->getTimeFormat());
+    m_scheduleView->setTimeFormat((m_calendarManager->getTimeShowType() ? "AP " : "") + m_calendarManager->getTimeFormat());
     //获取需要显示的时间
     QVector<QDate> _monthDate = m_calendarManager->getMonthDate(getSelectDate().year(), getSelectDate().month());
     m_daymonthView->setShowDate(_monthDate, getSelectDate(), getCurrendDateTime().date());
@@ -287,8 +287,12 @@ void CDayWindow::initUI()
     leftMainLayout->setContentsMargins(0, 0, 0, 0);
     leftMainLayout->addLayout(leftLayout);
     leftMainLayout->addWidget(m_verline);
-
     leftMainLayout->addWidget(m_daymonthView);
+
+    leftMainLayout->setStretchFactor(leftLayout, 3);
+    leftMainLayout->setStretchFactor(m_verline, 1);
+    leftMainLayout->setStretchFactor(m_daymonthView, 2);
+
     m_leftground = new CustomFrame();
     m_leftground->setRoundState(true, true, true, true);
     m_leftground->setLayout(leftMainLayout);
@@ -369,14 +373,6 @@ void CDayWindow::slotChangeSelectDate(const QDate &date)
     }
 }
 
-void CDayWindow::resizeEvent(QResizeEvent *event)
-{
-    Q_UNUSED(event);
-    qreal dw = 0.4 * width();
-    int dh = height() - 20;
-    m_daymonthView->setFixedSize(qRound(dw), dh);
-}
-
 void CDayWindow::slotIsDragging(bool &isDragging)
 {
     isDragging = m_scheduleView->IsDragging();
