@@ -28,6 +28,7 @@ DAccountManageModule::DAccountManageModule(QObject *parent)
     , m_syncFileManage(new SyncFileManage())
     , m_accountManagerDB(new DAccountManagerDataBase)
 {
+    m_isSupportUid = m_syncFileManage->getSyncoperation()->hasAvailable();
     //新文件路径
     QString newDbPath = getDBPath();
     QString newDB(newDbPath + "/" + "accountmanager.db");
@@ -42,7 +43,8 @@ DAccountManageModule::DAccountManageModule(QObject *parent)
 
     //根据获取到的帐户信息创建对应的帐户服务
     foreach (auto account, m_accountList) {
-        if(account->accountType() != DAccount::Account_Local){
+        //如果不支持云同步且帐户类型为UID则过滤
+        if(!m_isSupportUid && account->accountType() == DAccount::Account_UnionID){
             continue;
         }
         DAccountModule::Ptr accountModule = DAccountModule::Ptr(new DAccountModule(account));
@@ -64,9 +66,11 @@ DAccountManageModule::DAccountManageModule(QObject *parent)
     connect(&m_timer,&QTimer::timeout,this,&DAccountManageModule::slotClientIsOpen);
     m_timer.start(2000);
 
-    //暂时屏蔽云同步部分
-//    QObject::connect(m_syncFileManage->getSyncoperation(), &Syncoperation::signalLoginStatusChange, this, &DAccountManageModule::slotUidLoginStatueChange);
-//    QObject::connect(m_syncFileManage->getSyncoperation(), &Syncoperation::SwitcherChange, this, &DAccountManageModule::slotSwitcherChange);
+    if(m_isSupportUid) {
+        QObject::connect(m_syncFileManage->getSyncoperation(), &Syncoperation::signalLoginStatusChange, this, &DAccountManageModule::slotUidLoginStatueChange);
+        QObject::connect(m_syncFileManage->getSyncoperation(), &Syncoperation::SwitcherChange, this, &DAccountManageModule::slotSwitcherChange);
+    }
+
     //第一次启动加载完成后发送帐户改变信号
     // emit signalLoginStatusChange();
 }
@@ -106,8 +110,7 @@ void DAccountManageModule::setCalendarGeneralSettings(const QString &cgSet)
 
 int DAccountManageModule::getfirstDayOfWeek()
 {
-    DCalendarGeneralSettings::Ptr cgSetPtr = DCalendarGeneralSettings::Ptr(new DCalendarGeneralSettings);
-    return static_cast<int>(cgSetPtr->firstDayOfWeek());
+    return static_cast<int>(m_generalSetting->firstDayOfWeek());
 }
 
 void DAccountManageModule::setFirstDayOfWeek(const int firstday)
@@ -125,8 +128,7 @@ void DAccountManageModule::setFirstDayOfWeek(const int firstday)
 
 int DAccountManageModule::getTimeFormatType()
 {
-    DCalendarGeneralSettings::Ptr cgSetPtr = DCalendarGeneralSettings::Ptr(new DCalendarGeneralSettings);
-    return static_cast<int>(cgSetPtr->timeShowType());
+    return static_cast<int>(m_generalSetting->timeShowType());
 }
 
 void DAccountManageModule::setTimeFormatType(const int timeType)
@@ -190,6 +192,11 @@ void DAccountManageModule::logout()
     m_syncFileManage->getSyncoperation()->optlogout();
 }
 
+bool DAccountManageModule::isSupportUid()
+{
+    return m_isSupportUid;
+}
+
 void DAccountManageModule::calendarOpen(bool isOpen)
 {
     //每次开启日历时需要同步数据
@@ -205,8 +212,8 @@ void DAccountManageModule::unionIDDataMerging()
 {
     m_accountList = m_accountManagerDB->getAccountList();
 
-    //暂时屏蔽云同步部分
-    {
+    //如果不支持云同步
+    if(!m_isSupportUid) {
         DAccount::Ptr unionidDB;
         auto hasUnionid = [ =, &unionidDB](const DAccount::Ptr & account) {
             if (account->accountType() == DAccount::Account_UnionID) {
@@ -223,7 +230,6 @@ void DAccountManageModule::unionIDDataMerging()
         return;
     }
 
-
     DAccount::Ptr accountUnionid = m_syncFileManage->getuserInfo();
 
     DAccount::Ptr unionidDB;
@@ -342,9 +348,10 @@ void DAccountManageModule::slotTimeFormatType(const int timeType)
 void DAccountManageModule::slotUidLoginStatueChange(const int status)
 {
     //因为有时登录成功会触发2次
-    static int oldStatus = 0;
-    if (oldStatus != status) {
-        oldStatus = status;
+    static QList<int> oldStatus{};
+    //登录成功后会触发多次，状态也不一致。比如登录后会连续触发 1 -- 4 -- 1 信号
+    if (!oldStatus.contains(status)) {
+        oldStatus.append(status);
     } else {
         //如果当前状态和上次状态一直，则退出
         return;
@@ -355,16 +362,22 @@ void DAccountManageModule::slotUidLoginStatueChange(const int status)
 
     switch (status) {
     case 1: {
+        //移除登出状态
+        if(oldStatus.contains(3)){
+            oldStatus.removeAt(oldStatus.indexOf(3));
+        }
+
         //登陆成功
         DAccount::Ptr accountUnionid = m_syncFileManage->getuserInfo();
         if (accountUnionid.isNull() || accountUnionid->accountName().isEmpty()) {
             qWarning() << "Error getting account information";
-            oldStatus = 0;
+            oldStatus.removeAt(oldStatus.indexOf(1));
             return;
         }
         addUIdAccount(accountUnionid);
 
         DAccountModule::Ptr accountModule = DAccountModule::Ptr(new DAccountModule(accountUnionid));
+        QObject::connect(accountModule.data(), &DAccountModule::signalSettingChange, this, &DAccountManageModule::slotSettingChange);
         m_accountModuleMap[accountUnionid->accountID()] = accountModule;
         DAccountService::Ptr accountService = DAccountService::Ptr(new DAccountService(accountUnionid->dbusPath(), accountUnionid->dbusInterface(), accountModule, this));
         if (!sessionBus.registerObject(accountService->getPath(), accountService->getInterface(), accountService.data(), options)) {
@@ -377,6 +390,10 @@ void DAccountManageModule::slotUidLoginStatueChange(const int status)
         }
     } break;
     case 3: {
+        //移除登录状态
+        if(oldStatus.contains(1)){
+            oldStatus.removeAt(oldStatus.indexOf(1));
+        }
         //登出
         if (m_AccountServiceMap[DAccount::Type::Account_UnionID].size() > 0) {
             //如果存在UID帐户则移除相关信息
