@@ -34,6 +34,9 @@
 #include "ddatasyncbase.h"
 #include "dbusnotify.h"
 
+#include <QDir>
+#include <QFile>
+
 #define UPDATEREMINDJOBTIMEINTERVAL 1000 * 60 * 10 //提醒任务更新时间间隔毫秒数（10分钟）
 
 DAccountModule::DAccountModule(const DAccount::Ptr &account, QObject *parent)
@@ -93,7 +96,6 @@ int DAccountModule::getAccountState()
 
 void DAccountModule::setAccountState(const int accountState)
 {
-    qInfo() << accountState;
     if (int(m_account->accountState()) != accountState) {
         m_account->setAccountState(static_cast<DAccount::AccountState>(accountState));
         m_accountDB->updateAccountInfo();
@@ -194,16 +196,6 @@ bool DAccountModule::deleteScheduleTypeByID(const QString &typeID)
         //更新提醒任务
         updateRemindSchedules(false);
         m_accountDB->deleteSchedulesByScheduleTypeID(typeID, !m_account->isNetWorkAccount());
-        //操作内容给任务列表
-        if (m_account->isNetWorkAccount()) {
-            DUploadTaskData::Ptr uploadTask(new DUploadTaskData);
-            uploadTask->setTaskType(DUploadTaskData::TaskType::Delete);
-            uploadTask->setTaskObject(DUploadTaskData::Task_ScheduleType);
-            uploadTask->setObjectId(typeID);
-            m_accountDB->addUploadTask(uploadTask);
-            //开启上传任务
-            uploadNetWorkAccountData();
-        }
         emit signalScheduleUpdate();
     }
     DScheduleType::Ptr scheduleType = m_accountDB->getScheduleTypeByID(typeID);
@@ -212,12 +204,31 @@ bool DAccountModule::deleteScheduleTypeByID(const QString &typeID)
         QStringList scheduleIDList = m_accountDB->getScheduleIDListByTypeID(typeID);
         //弱删除
         m_accountDB->deleteScheduleTypeByID(typeID);
-        //TODO:发送操作内容给任务列表
 
-        //TODO:如果颜色不为系统类型则删除
+        //发送操作内容给任务列表
+        DUploadTaskData::Ptr uploadTask(new DUploadTaskData);
+        uploadTask->setTaskType(DUploadTaskData::TaskType::Delete);
+        uploadTask->setTaskObject(DUploadTaskData::Task_ScheduleType);
+        uploadTask->setObjectId(typeID);
+        m_accountDB->addUploadTask(uploadTask);
 
+        //如果颜色不为系统类型则删除
+        if(scheduleType->typeColor().privilege() != DTypeColor::PriSystem){
+            m_accountDB->deleteTypeColor(scheduleType->typeColor().colorID());
+            DUploadTaskData::Ptr uploadTask(new DUploadTaskData);
+            uploadTask->setTaskType(DUploadTaskData::TaskType::Delete);
+            uploadTask->setTaskObject(DUploadTaskData::Task_Color);
+            uploadTask->setObjectId(scheduleType->typeColor().colorID());
+            m_accountDB->addUploadTask(uploadTask);
+        }
+
+        //开启上传任务
+        uploadNetWorkAccountData();
     } else {
         m_accountDB->deleteScheduleTypeByID(typeID, 1);
+        if(scheduleType->typeColor().privilege() != DTypeColor::PriSystem){
+            m_accountDB->deleteTypeColor(scheduleType->typeColor().colorID());
+        }
     }
     if (scheduleType.isNull()) {
         qWarning() << "scheduleType isNull, typeID:" << typeID;
@@ -266,7 +277,8 @@ bool DAccountModule::updateScheduleType(const QString &typeInfo)
                 //添加创建颜色任务
                 if (m_account->isNetWorkAccount()) {
                     DUploadTaskData::Ptr uploadTask(new DUploadTaskData);
-                    uploadTask->setTaskType(DUploadTaskData::TaskType::Delete);
+//                    uploadTask->setTaskType(DUploadTaskData::TaskType::Delete);
+                    uploadTask->setTaskType(DUploadTaskData::TaskType::Create);
                     uploadTask->setTaskObject(DUploadTaskData::Task_Color);
                     uploadTask->setObjectId(typeColor->colorID());
                     m_accountDB->addUploadTask(uploadTask);
@@ -674,6 +686,21 @@ QString DAccountModule::getDtLastUpdate()
 void DAccountModule::removeDB()
 {
     m_accountDB->removeDB();
+    //如果为uid帐户退出则清空目录下所有关于uid的数据库文件
+    //解决在某些条件下数据库没有被移除的问题（自测未发现）
+    if(account()->accountType() == DAccount::Type::Account_UnionID){
+        QString dbPatch = getHomeConfigPath().append(QString("/deepin/dde-calendar-service/"));
+        QDir dir(dbPatch);
+        if (dir.exists()) {
+            QStringList filters;
+            filters << QString("account_uid_*");
+            dir.setFilter(QDir::Files | QDir::NoSymLinks);
+            dir.setNameFilters(filters);
+            for (uint i = 0; i < dir.count(); ++i) {
+                QFile::remove(dbPatch + dir[i]);
+            }
+        }
+    }
 }
 
 QMap<QDate, DSchedule::List> DAccountModule::getScheduleTimesOn(const QDateTime &dtStart, const QDateTime &dtEnd, const DSchedule::List &scheduleList, bool extend)
@@ -734,12 +761,22 @@ QMap<QDate, DSchedule::List> DAccountModule::getScheduleTimesOn(const QDateTime
         } else {
             //普通日程
             //如果在查询时间范围内
-            if (!(schedule->dtEnd() < dtStart || schedule->dtStart() > dtEnd)) {
+            QDateTime queryDtStart = dtStart;
+            //如果日程为全天日程，则查询的开始时间设置为0点，因为全天日程的开始和结束时间都是0点
+            if(schedule->allDay()){
+                queryDtStart.setTime(QTime(0,0,0));
+            }
+            if (!(schedule->dtEnd() < queryDtStart || schedule->dtStart() > dtEnd)) {
                 if (extend && schedule->isMultiDay()) {
                     //需要扩展的天数
                     int extenddays = static_cast<int>(schedule->dtStart().daysTo(schedule->dtEnd()));
                     for (int i = 0; i <= extenddays; ++i) {
-                        m_scheduleMap[schedule->dtStart().date().addDays(i)].append(schedule);
+                        //如果扩展的日期在查询范围内则添加，否则退出
+                        if(m_scheduleMap.contains(schedule->dtStart().date().addDays(i))){
+                            m_scheduleMap[schedule->dtStart().date().addDays(i)].append(schedule);
+                        } else {
+                            break;
+                        }
                     }
                 } else {
                     m_scheduleMap[schedule->dtStart().date()].append(schedule);
@@ -777,10 +814,15 @@ DSchedule::List DAccountModule::getFestivalSchedule(const QDateTime &dtStart, co
 
 void DAccountModule::extendRecurrence(DSchedule::Map &scheduleMap, const DSchedule::Ptr &schedule, const QDateTime &dtStart, const QDateTime &dtEnd, bool extend)
 {
+    QDateTime queryDtStart = dtStart;
+    //如果日程为全天日程，则查询的开始时间设置为0点，因为全天日程的开始和结束时间都是0点
+    if(schedule->allDay()){
+        queryDtStart.setTime(QTime(0,0,0));
+    }
     if (schedule->recurs()) {
         //获取日程的开始结束时间差
         qint64 interval = schedule->dtStart().secsTo(schedule->dtEnd());
-        QList<QDateTime> dtList = schedule->recurrence()->timesInInterval(dtStart, dtEnd);
+        QList<QDateTime> dtList = schedule->recurrence()->timesInInterval(queryDtStart, dtEnd);
         foreach (auto &dt, dtList) {
             QDateTime scheduleDtEnd = dt.addSecs(interval);
             DSchedule::Ptr newSchedule = DSchedule::Ptr(schedule->clone());
@@ -802,7 +844,7 @@ void DAccountModule::extendRecurrence(DSchedule::Map &scheduleMap, const DSchedu
             }
         }
     } else {
-        if (!(schedule->dtStart() > dtEnd || schedule->dtEnd() < dtStart)) {
+        if (!(schedule->dtStart() > dtEnd || schedule->dtEnd() < queryDtStart)) {
             scheduleMap[schedule->dtStart().date()].append(schedule);
         }
     }
@@ -906,6 +948,8 @@ void DAccountModule::slotSyncState(const int syncState)
         //执行正常
         m_account->setSyncState(DAccount::Sync_Normal);
         m_accountDB->updateAccountInfo();
+        //同步成功后更新提醒任务
+        updateRemindSchedules(false);
         break;
     case 7506:
         //网络异常
@@ -916,6 +960,7 @@ void DAccountModule::slotSyncState(const int syncState)
         m_account->setSyncState(DAccount::Sync_StorageFull);
         break;
     default:
+        qWarning()<<"syncState:"<<syncState<<"fun:"<<__FUNCTION__<<" line:"<<__LINE__;
         //默认服务器异常
         m_account->setSyncState(DAccount::Sync_ServerException);
         break;
