@@ -20,15 +20,13 @@
 */
 #include "dunioniddbus.h"
 
-#include <QJsonDocument>
-#include <QJsonObject>
-#include <QJsonObject>
-
 DUnionIDDbus::DUnionIDDbus(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
     : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
 {
     if (!this->isValid()) {
         qWarning() << "Error connecting remote object, service:" << this->service() << ",path:" << this->path() << ",interface" << this->interface();
+        qWarning() << this->lastError();
+        
     }
 }
 
