@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="hu">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
 <context>
     <name>AccountItem</name>
     <message>
@@ -34,7 +32,7 @@
     <message>
         <location filename="../calendar-client/src/dataManage/accountmanager.cpp" line="227"/>
         <source>Event types</source>
-        <translation type="unfinished">Esemény típusok</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -193,8 +191,8 @@
     <name>CScheduleDlg</name>
     <message>
         <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="58"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="608"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="901"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="612"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="908"/>
         <source>New Event</source>
         <translation>Új esemény</translation>
     </message>
@@ -204,255 +202,255 @@
         <translation>Esemény szerkesztése</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="265"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="269"/>
         <source>End time must be greater than start time</source>
         <translation>A befejezés időpontjának a kezdés időpontjánál későbbre kell esnie</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="266"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="270"/>
         <source>OK</source>
         <comment>button</comment>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="490"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="519"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1113"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1148"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1402"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1406"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="494"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="523"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1120"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1155"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1409"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1413"/>
         <source>Never</source>
         <translation>Soha</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="491"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="495"/>
         <source>At time of event</source>
         <translation>Az esemény időpontjában</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="492"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="496"/>
         <source>15 minutes before</source>
         <translation>15 perccel előtte</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="493"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="497"/>
         <source>30 minutes before</source>
         <translation>30 perccel előtte</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="494"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="498"/>
         <source>1 hour before</source>
         <translation>1 órával előtte</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="495"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="521"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="499"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="525"/>
         <source>1 day before</source>
         <translation>1 nappal előtte</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="496"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="522"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="500"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="526"/>
         <source>2 days before</source>
         <translation>2 nappal előtte</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="497"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="523"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="501"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="527"/>
         <source>1 week before</source>
         <translation>1 héttel előtte</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="520"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="524"/>
         <source>On start day (9:00 AM)</source>
         <translation>Esemény kezdete napján (De. 09:00)</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="567"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="774"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1169"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1170"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="571"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="778"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1176"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1177"/>
         <source>time(s)</source>
         <translation>Időpont(ok)</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="581"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="585"/>
         <source>Enter a name please</source>
         <translation>Kérjük adjon meg egy nevet</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="676"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="680"/>
         <source>The name can not only contain whitespaces</source>
         <translation>A név nem tartalmazhat csak szóközöket</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="732"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="851"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="736"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="858"/>
         <source>Type:</source>
         <translation>Típus:</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="737"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="886"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="741"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="893"/>
         <source>Description:</source>
         <translation>Leírás:</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="742"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="923"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="746"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="930"/>
         <source>All Day:</source>
         <translation>Egész nap:</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="747"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="989"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="751"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="996"/>
         <source>Starts:</source>
         <translation>Kezdés:</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="752"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1030"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="756"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1037"/>
         <source>Ends:</source>
         <translation>Befejezés:</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="757"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1070"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="761"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1077"/>
         <source>Remind Me:</source>
         <translation>Emlékeztessen:</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="762"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1102"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="766"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1109"/>
         <source>Repeat:</source>
         <translation>Ismétlés:</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="767"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1136"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="771"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1143"/>
         <source>End Repeat:</source>
         <translation>Ismétlés vége:</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="823"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="827"/>
         <source>Calendar account:</source>
         <translation>Naptár fiók:</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="824"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="828"/>
         <source>Calendar account</source>
         <translation>Naptár fiók</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="848"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="855"/>
         <source>Type</source>
         <translation>Típus</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="890"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="897"/>
         <source>Description</source>
         <translation>Leírás</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="920"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="927"/>
         <source>All Day</source>
         <translation>Egész nap</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="944"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="951"/>
         <source>Time:</source>
         <translation>Idő:</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="945"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="952"/>
         <source>Time</source>
         <translation>Idő</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="952"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="959"/>
         <source>Solar</source>
         <translation>Nap</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="953"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="960"/>
         <source>Lunar</source>
         <translation>Hold</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="986"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="993"/>
         <source>Starts</source>
         <translation>Kezdés</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1027"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1034"/>
         <source>Ends</source>
         <translation>Befejezés</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1072"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1079"/>
         <source>Remind Me</source>
         <translation>Emlékeztessen</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1099"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1106"/>
         <source>Repeat</source>
         <translation>Ismétlés</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1114"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1407"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1121"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1414"/>
         <source>Daily</source>
         <translation>Naponta</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1115"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1408"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1122"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1415"/>
         <source>Weekdays</source>
         <translation>Hétköznapokon</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1116"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1409"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1123"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1416"/>
         <source>Weekly</source>
         <translation>Hetente</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1117"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1403"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1124"/>
         <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1410"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1417"/>
         <source>Monthly</source>
         <translation>Havonta</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1118"/>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1404"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1125"/>
         <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1411"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1418"/>
         <source>Yearly</source>
         <translation>Évente</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1138"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1145"/>
         <source>End Repeat</source>
         <translation>Ismétlés vége</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1149"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1156"/>
         <source>After</source>
         <translation>Utána</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1150"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1157"/>
         <source>On</source>
         <translation>Ekkor</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1220"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1227"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>Mégsem</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1221"/>
+        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1228"/>
         <source>Save</source>
         <comment>button</comment>
         <translation>Mentés</translation>
@@ -637,57 +635,57 @@
 <context>
     <name>CSettingDialog</name>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="321"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="351"/>
         <source>Sunday</source>
         <translation>Vasárnap</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="322"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="352"/>
         <source>Monday</source>
         <translation>Hétfő</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="339"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="369"/>
         <source>24-hour clock</source>
         <translation>24 órás óra formátum</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="340"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="370"/>
         <source>12-hour clock</source>
         <translation>12 órás óra formátum</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="373"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="403"/>
         <source>Manual</source>
         <translation>Manuális</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="374"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="404"/>
         <source>15 mins</source>
         <translation>15 perc</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="375"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="405"/>
         <source>30 mins</source>
         <translation>30 perc</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="376"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="406"/>
         <source>1 hour</source>
         <translation>1 óra</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="377"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="407"/>
         <source>24 hours</source>
         <translation>24 óra</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="388"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="418"/>
         <source>Sync Now</source>
         <translation>Szinkronizálás most</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="531"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="561"/>
         <source>Last sync</source>
         <translation>Utolsó szinkronizálás</translation>
     </message>
@@ -715,22 +713,22 @@
     <message>
         <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="46"/>
         <source>Y</source>
-        <translation>Éves</translation>
+        <translation>Év</translation>
     </message>
     <message>
         <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="58"/>
         <source>M</source>
-        <translation>Havi</translation>
+        <translation>Hó</translation>
     </message>
     <message>
         <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="66"/>
         <source>W</source>
-        <translation>Heti</translation>
+        <translation>Hét</translation>
     </message>
     <message>
         <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="74"/>
         <source>D</source>
-        <translation>Napi</translation>
+        <translation>Nap</translation>
     </message>
     <message>
         <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="108"/>
@@ -744,37 +742,37 @@
     <message>
         <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
         <source>Sun</source>
-        <translation>Vasárnap</translation>
+        <translation>V.</translation>
     </message>
     <message>
         <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
         <source>Mon</source>
-        <translation>Hétfő</translation>
+        <translation>H.</translation>
     </message>
     <message>
         <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
         <source>Tue</source>
-        <translation>Kedd</translation>
+        <translation>K.</translation>
     </message>
     <message>
         <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
         <source>Wed</source>
-        <translation>Szerda</translation>
+        <translation>Sze.</translation>
     </message>
     <message>
         <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
         <source>Thu</source>
-        <translation>Csütörtök</translation>
+        <translation>Cs.</translation>
     </message>
     <message>
         <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
         <source>Fri</source>
-        <translation>Péntek</translation>
+        <translation>P.</translation>
     </message>
     <message>
         <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
         <source>Sat</source>
-        <translation>Szombat</translation>
+        <translation>Szo.</translation>
     </message>
 </context>
 <context>
@@ -840,7 +838,7 @@
     <message>
         <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="376"/>
         <source>Privacy Policy</source>
-        <translation type="unfinished"></translation>
+        <translation>Adatvédelmi irányelvek</translation>
     </message>
     <message>
         <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="941"/>
@@ -866,90 +864,6 @@
         <translation>Egész nap</translation>
     </message>
 </context>
-<context>
-    <name>DAccountDataBase</name>
-    <message>
-        <location filename="../calendar-service/src/dbmanager/daccountdatabase.cpp" line="1158"/>
-        <source>Work</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/dbmanager/daccountdatabase.cpp" line="1160"/>
-        <source>Life</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/dbmanager/daccountdatabase.cpp" line="1162"/>
-        <source>Other</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>DAlarmManager</name>
-    <message>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="172"/>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="179"/>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="184"/>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="194"/>
-        <source>Close</source>
-        <comment>button</comment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="175"/>
-        <source>One day before start</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="180"/>
-        <source>Remind me tomorrow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="185"/>
-        <source>Remind me later</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="187"/>
-        <source>15 mins later</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="188"/>
-        <source>1 hour later</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="189"/>
-        <source>4 hours later</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="190"/>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="268"/>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="279"/>
-        <source>Tomorrow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="197"/>
-        <source>Schedule Reminder</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="236"/>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="245"/>
-        <source>%1 to %2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="265"/>
-        <location filename="../calendar-service/src/alarmManager/dalarmmanager.cpp" line="276"/>
-        <source>Today</source>
-        <translation type="unfinished">Ma</translation>
-    </message>
-</context>
 <context>
     <name>DragInfoGraphicsView</name>
     <message>
@@ -1001,12 +915,14 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="88"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="103"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="134"/>
         <source>Manage calendar</source>
         <translation>Naptár kezelése</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="104"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="119"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="138"/>
         <source>Event types</source>
         <translation>Esemény típusok</translation>
     </message>
@@ -1016,48 +932,48 @@
         <translation>Felhasználói fiók beállítások</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="48"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="49"/>
         <source>Account</source>
         <translation>Felhasználói fiók</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="56"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="60"/>
         <source>Select items to be synced</source>
         <translation>Válassza ki a szinkronizálni kívánt elemeket</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="59"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="63"/>
         <source>Events</source>
         <translation>Események</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="66"/>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="119"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="70"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="153"/>
         <source>General settings</source>
         <translation>Általános beállítások</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="73"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="81"/>
         <source>Sync interval</source>
         <translation>Szinkronizálási időintervallum</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="96"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="111"/>
         <source>Calendar account</source>
         <translation>Naptár fiók</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="123"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="157"/>
         <source>General</source>
         <translation>Általános</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="127"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="161"/>
         <source>First day of week</source>
         <translation>A hét első napja</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="135"/>
+        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="169"/>
         <source>Time</source>
         <translation>Idő</translation>
     </message>
@@ -1190,13 +1106,13 @@
 <context>
     <name>UserloginWidget</name>
     <message>
-        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="62"/>
+        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="63"/>
         <source>Sign In</source>
         <comment>button</comment>
         <translation>Bejelentkezés</translation>
     </message>
     <message>
-        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="63"/>
+        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="64"/>
         <source>Sign Out</source>
         <comment>button</comment>
         <translation>Kijelentkezés</translation>
@@ -1226,4 +1142,4 @@
         <translation>Ma</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
